
-- If lookup table does not exist
-- Create lookup table with sequence numbers as ID
-- Insert 10000 rows into lookup table
IF NOT EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[Seapine_Tally]')
AND  OBJECTPROPERTY(id, N'IsTable') = 1)
CREATE TABLE [dbo].[Seapine_Tally](
	[ID] [int] NOT NULL,
	PRIMARY KEY(ID)
);

DECLARE @Index INT ;
    SET @Index = (SELECT MAX(ID) FROM [dbo].[Seapine_Tally]);
	SET @Index = ISNULL(@Index, 0);
    SET @Index = @Index + 1 ;
    WHILE @Index <= 10000 BEGIN 
	    INSERT [dbo].[Seapine_Tally] (ID) VALUES (@Index) ;
	    SET @Index = @Index + 1 ;
    END
GO

-- If defect customfield view exists, drop it
IF EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[DEFECT_CustomFields_View]')
AND  OBJECTPROPERTY(id, N'IsView') = 1)
DROP VIEW [dbo].[DEFECT_CustomFields_View]
GO
 
-- Defect CustomFields view
CREATE VIEW [dbo].[DEFECT_CustomFields_View] AS
SELECT st.ID, cv.IDRECORD, 
	   cv.ProjectID,
	   cv.ParentID,
	   cv.IDCUSTREC,
       CONVERT(NUMERIC(10, 0), CONVERT(BIGINT, (SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID,
						CASE 
							WHEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0 
							THEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID
							ELSE 0
						END)))) AS CustmValID
FROM Seapine_Tally st, CUSTMVAL cv, FLDDFNTN fd
WHERE	ID <= LEN(',' + CONVERT(VARCHAR, CUSTVALUE) + ',') 
		AND SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID - 1, 1) = ',' 
		AND CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0
		AND CONVERT(VARCHAR, CUSTVALUE) != '4294967295' 
		AND cv.PROJECTID = fd.PROJECTID
		AND cv.IDCUSTREC = fd.IDRECORD
		AND	fd.FIELDTYPE = 1;
GO

-- If testcase customfield view exists, drop it
IF EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[TESTCASE_CustomFields_View]')
AND  OBJECTPROPERTY(id, N'IsView') = 1)
DROP VIEW [dbo].[TESTCASE_CustomFields_View]
GO
 
-- Testcase CustomFields view
CREATE VIEW [dbo].[TESTCASE_CustomFields_View] AS
SELECT st.ID, cv.IDRECORD, 
	   cv.ProjectID,
	   cv.ParentID,
	   cv.IDCUSTREC,
       CONVERT(NUMERIC(10, 0), CONVERT(BIGINT, (SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID,
						CASE 
							WHEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0 
							THEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID
							ELSE 0
						END)))) AS CustmValID
FROM Seapine_Tally st, CUSTTCVAL cv, FLDDFNTN fd
WHERE	ID <= LEN(',' + CONVERT(VARCHAR, CUSTVALUE) + ',') 
		AND SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID - 1, 1) = ',' 
		AND CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0
		AND CONVERT(VARCHAR, CUSTVALUE) != '4294967295' 
		AND cv.PROJECTID = fd.PROJECTID
		AND cv.IDCUSTREC = fd.IDRECORD
		AND	fd.FIELDTYPE = 1;
GO

-- If TestRun customfield view exists, drop it
IF EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[TESTRUN_CustomFields_View]')
AND  OBJECTPROPERTY(id, N'IsView') = 1)
DROP VIEW [dbo].[TESTRUN_CustomFields_View]
GO
 
-- TestRun CustomFields view
CREATE VIEW [dbo].[TESTRUN_CustomFields_View] AS
SELECT st.ID, cv.IDRECORD, 
	   cv.ProjectID,
	   cv.ParentID,
	   cv.IDCUSTREC,
       CONVERT(NUMERIC(10, 0), CONVERT(BIGINT, (SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID,
						CASE 
							WHEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0 
							THEN CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID
							ELSE 0
						END)))) AS CustmValID
FROM Seapine_Tally st, CUSTTRVAL cv, FLDDFNTN fd
WHERE	ID <= LEN(',' + CONVERT(VARCHAR, CUSTVALUE) + ',') 
		AND SUBSTRING(',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID - 1, 1) = ',' 
		AND CHARINDEX(',' , ',' + CONVERT(VARCHAR, CUSTVALUE) + ',' , ID) - ID > 0
		AND CONVERT(VARCHAR, CUSTVALUE) != '4294967295' 
		AND cv.PROJECTID = fd.PROJECTID
		AND cv.IDCUSTREC = fd.IDRECORD
		AND	fd.FIELDTYPE = 1;
GO

-- If defect notify users view exists, drop it
IF EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[DEFECT_Notify_Users_View]')
AND  OBJECTPROPERTY(id, N'IsView') = 1)
DROP VIEW [dbo].[DEFECT_Notify_Users_View]
GO

--Notify users view
CREATE VIEW [dbo].[DEFECT_Notify_Users_View] AS
SELECT ID, IDRECORD, 
	   ProjectID,    
       CONVERT(NUMERIC(10, 0), CONVERT(BIGINT, (SUBSTRING(' ' + NOTIFY + ' ' , ID,
						CASE 
							WHEN CHARINDEX(' ' , ' ' + NOTIFY + ' ' , ID) - ID > 0 THEN CHARINDEX(' ' , ' ' + NOTIFY + ' ' , ID) - ID
							ELSE 0
						END)))) AS UserID
FROM dbo.Seapine_Tally, dbo.DEFECTS
WHERE	ID <= LEN(' ' + NOTIFY + ' ') 
		AND SUBSTRING(' ' + NOTIFY + ' ' , ID - 1, 1) = ' ' 
		AND CHARINDEX(' ' , ' ' + NOTIFY + ' ' , ID) - ID > 0
		AND NOTIFY != '4294967295';
GO

-- If defect assigned users view exists, drop it
IF EXISTS (SELECT id FROM [dbo].SYSOBJECTS  
WHERE id = OBJECT_ID(N'[dbo].[DEFECTEVTS_Assigned_Users_View]')
AND  OBJECTPROPERTY(id, N'IsView') = 1)
DROP VIEW [dbo].[DEFECTEVTS_Assigned_Users_View]
GO

-- Defect Assigned To view
CREATE VIEW [dbo].[DEFECTEVTS_Assigned_Users_View] AS
SELECT ID,
	   IDRECORD, 
       PROJECTID, 
       PARENTID, 
       EVTDEFID,
	   ORDERNUM,
       CONVERT(NUMERIC(10, 0), CONVERT(BIGINT, (SUBSTRING(' ' + ASGNDUSERS + ' ' , ID,
						CASE 
							WHEN CHARINDEX(' ' , ' ' + ASGNDUSERS + ' ' , ID) - ID > 0 THEN CHARINDEX(' ' , ' ' + ASGNDUSERS + ' ' , ID) - ID
							ELSE 0
						END)))) AS UserID
FROM Seapine_Tally, DEFECTEVTS de
WHERE	ID <= LEN(' ' + ASGNDUSERS + ' ') 
		AND SUBSTRING(' ' + ASGNDUSERS + ' ' , ID - 1, 1) = ' ' 
		AND CHARINDEX(' ' , ' ' + ASGNDUSERS + ' ' , ID) - ID > 0
		AND ORDERNUM >= (SELECT MAX(ORDERNUM) 
						 FROM DEFECTEVTS tmp
						 WHERE ASGNDUSERS != '' and PROJECTID = de.PROJECTID and PARENTID = de.PARENTID)
		AND DEFASGEFF != 3
		AND ASGNDUSERS != '4294967295';
GO